Welcome to ClientVPS Mirrors

Help for package ImCluster
Type: Package
Title: Efficiency of Cluster Sampling for Crop Surveys
Version: 0.1.0
Author: M. Iqbal Jeelani [aut, cre], Fehim Jeelani [aut], Shakeel Ahmad Mir [aut], Showkat Maqbool [aut], Syed Naseem Geelani [aut], Mushtaq Ahmad Lone [aut], Md Yeasin [aut]
Maintainer: M. Iqbal Jeelani <jeelani.miqbal@gmail.com>
Description: Cluster sampling is a valuable approach when constructing a comprehensive list of individual units is challenging. It provides operational and cost advantages. This package is designed to test the efficiency of cluster sampling in terms cluster variance and design effect in context to crop surveys. This package has been developed using the algorithm of Iqbal et al. (2018) <doi:10.19080/BBOAJ.2018.05.555673>.
License: GPL-3
Encoding: UTF-8
Imports: stats, dplyr
RoxygenNote: 7.2.1
Depends: R (≥ 2.10)
NeedsCompilation: no
Packaged: 2023-11-07 16:39:25 UTC; YEASIN
Repository: CRAN
Date/Publication: 2023-11-07 19:40:05 UTC

Efficiency of Cluster Sampling for Crop Surveys

Description

Efficiency of Cluster Sampling for Crop Surveys

Usage

ImCluster(x, N = NULL)

Arguments

x

Datasets

N

Number of clusters

Value

References

Examples

N_clusters <- 105
orchards_per_cluster <- 4
data <- matrix(rnorm(N_clusters * orchards_per_cluster), nrow = orchards_per_cluster, byrow = TRUE)
colnames(data) <- paste0("Cluster_", 1:N_clusters)
demo_data <- data.frame(data)
result_imcluster <- ImCluster(demo_data, N_clusters)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.